Skip to main content

grz-cli

A command-line tool for validating, encrypting, and uploading submissions to a genomDE Model Project GDC (Genome Data Center).

Table of Contents

Installation

Requirements

The current version of the tool requires the working directory to have at least as much free disk space as the total size of the data being submitted.

Beside of the disk space requirements for the submission data, this tool also requires a Linux environment. For example:

  • Linux server
  • Virtual machine running Linux
  • Docker container
  • Windows Subsystem for Linux

Using Conda (recommended)

If Conda is not yet available on your system, we recommend to install it through the Miniforge Conda installer by running the following commands:

curl -L -O "https://github.com/conda-forge/miniforge/releases/latest/download/Miniforge3-$(uname)-$(uname -m).sh"
bash Miniforge3-$(uname)-$(uname -m).sh

Next, install the grz-cli tool:

conda create -n grz-tools -c conda-forge -c bioconda grz-cli
conda activate grz-tools
grz-cli --help

Updating

Use the following command to update the tool:

conda update -n grz-tools -c conda-forge -c bioconda grz-cli

Using pip (not recommended)

While installation via pip is possible, it is not recommended because users should create/manage a Python virtual environment and must ensure that the correct Python version is being used.

pip install grz-cli

Updating

Use the following command to update the tool:

pip upgrade grz-cli

Using Docker

Docker images are available via biocontainers at https://biocontainers.pro/tools/grz-cli.

The build process can take at least a few days after the Bioconda release, so double-check that the latest version in Bioconda is also the latest Docker image version.

Usage

Configuration

The configuration file will be provided by your associated GRZ. Do not create this file as an LE.

The tool requires a configuration file in YAML format to specify the S3 API parameters and other validation options.

This file may be placed at ~/.config/grz-cli/config.yaml or provided each time to grz-cli using the --config-file option on the command line.

The S3 secrets can either be directly within the config file or as defined with the usual AWS environment variables: AWS_ACCESS_KEY_ID and AWS_SECRET_ACCESS_KEY.

Submission Layout

It is recommended to have the following folder structure for a single submission:

EXAMPLE_SUBMISSION
├── files
│   ├── aaaaaaaa00000000aaaaaaaa00000000_blood_normal.read1.fastq.gz
│   ├── aaaaaaaa00000000aaaaaaaa00000000_blood_normal.read2.fastq.gz
│   ├── aaaaaaaa00000000aaaaaaaa00000000_blood_normal.vcf
│   ├── aaaaaaaa00000000aaaaaaaa00000000_blood_tumor.read1.fastq.gz
│   ├── aaaaaaaa00000000aaaaaaaa00000000_blood_tumor.read2.fastq.gz
│   ├── aaaaaaaa00000000aaaaaaaa00000000_blood_tumor.vcf
│   └─── target_regions.bed
└── metadata
    └── metadata.json

The only requirements are that metadata/metadata.json exists and the files/ directory contains all of the other files. Data files may be nested under subfolders inside files/ for better organization. For example, each donor could have their own folder for files.

Example submission procedure

After preparing your submission as outlined above, you can use the following command to validate, encrypt and upload the submission:

grz-cli submit --submission-dir EXAMPLE_SUBMISSION

Troubleshooting

In case of issues, please re-run your commands with grz-cli --log-level DEBUG --log-file path/to/write/file.log [...] and submit the log file to the GDC data steward.

Command-Line Interface

grz-cli provides a command-line interface with the following subcommands:

submit

The submit command is the recommended command for submitting data to genome data centers. It combines the validate, encrypt, and upload commands (see below).

  • -s, --submission-dir: Path to the submission directory containing both 'metadata/' and 'files/' directories [Required]
  • -c, --config-file: Path to config file [optional]
grz-cli submit --submission-dir foo

validate

It is recommended to run this command before continuing with encryption and upload.

  • --submission-dir: Path to the submission directory containing both 'metadata/' and 'files/' directories [Required]

Example usage:

grz_cli validate --submission-dir foo

encrypt

If a working directory is not provided, then the current directory is used automatically. Files are stored in a folder named encrypted_files as a sub-folder of the working directory.

  • -s, --submission-dir: Path to the submission directory containing both 'metadata/' and 'files/' directories [Required]
  • -c, --config-file: Path to config file [optional]
grz-cli encrypt --submission-dir foo

upload

Upload the submission into a S3 structure of a GRZ.

  • -s, --submission-dir: Path to the submission directory containing both metadata/ and encrypted_files/ directories [Required]
  • -c, --config-file: Path to config file [optional]

Example usage:

grz-cli upload --submission-dir foo

get-id

Available in grz-cli v1.2.0 or higher.

Compute and print the submission ID from a submission's JSON metadata.

This is useful in case you forget to store the ID printed during upload.

Example usage:

grz-cli get-id path/to/metadata.json

Contributing

Running unreleased/development versions

First, install uv. We recommend using Conda or Pixi.

After cloning the desired branch of the grz-tools repo locally, you can run grz-cli directly from the repo using:

uv run --project path/to/cloned/grz-tools grz-cli --help

Testing

Please note that binary files used for testing are managed with Git LFS, which will be needed to clone them locally with the git repository.

To run the tests, navigate to the root directory of your project and invoke pytest. Alternatively, install uv and tox and run uv run tox.

License

This project is licensed under the MIT License — see the LICENSE file for details.

Acknowledgements

Parts of Crypt4GH are used in modified form.

Metadata

Release files for grz-cli 2.0.0

For a detailed explanation of source distributions (sdists) and built distributions (wheels), please see the package formats documentation.

Source distribution (sdist)

Source distribution for grz-cli 2.0.0
File Size Uploaded
grz_cli-2.0.0.tar.gz 16.1 kB Details

Built distribution (wheel)

Table of built distributions (wheels) for grz-cli 2.0.0
File Interpreter ABI Platform
grz_cli-2.0.0-py3-none-any.whl Python 3 none any Details

Total release size: 28.3 kB

Release files / grz_cli-2.0.0.tar.gz

Download URL grz_cli-2.0.0.tar.gz
Size 16.1 kB
Tags Source
SHA-256 checksum
How to use checksums
d1b50dc72864d6179b68d9a20dd69363206dc94832b50331f861ffa214232080
BLAKE2b-256 checksum
How to use checksums
07416dc32d4ca9ddb0f216647640337a69f730341b752876cd559295619a3b24
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
Yes
Uploaded via twine/7.0.0 CPython/3.13.14

Provenance

Provenance describes where a file came from. On PyPI, provenance is shared via attestations, which provide a verifiable record of the build or publishing details. View details, limitations and caveats.

PyPI Publish Attestation

PyPI verified that this artifact, at this checksum, originated from the publisher listed below.

Signed by GitHub Actions, verified by PyPI on Aug 13, 2026.

Transparency log

Release files / grz_cli-2.0.0-py3-none-any.whl

Download URL grz_cli-2.0.0-py3-none-any.whl
Size 12.2 kB
Tags Python 3
SHA-256 checksum
How to use checksums
30aa31a68ce1c775d0101d37b97eefc815d9bbd415cda00c043e725050bfd4d2
BLAKE2b-256 checksum
How to use checksums
3ec3a3466aa52a79d101c723240f04cc48b3de73e79e019714b49a4cd083e2f2
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
Yes
Uploaded via twine/7.0.0 CPython/3.13.14

Provenance

Provenance describes where a file came from. On PyPI, provenance is shared via attestations, which provide a verifiable record of the build or publishing details. View details, limitations and caveats.

PyPI Publish Attestation

PyPI verified that this artifact, at this checksum, originated from the publisher listed below.

Signed by GitHub Actions, verified by PyPI on Aug 13, 2026.

Transparency log

Release history Release notifications | RSS feed

3.0.0

2 release files

This release

2.0.0 This release

2 release files

1.8.0

2 release files

1.7.2

2 release files

1.7.1

2 release files

1.7.0

2 release files

1.6.1

2 release files

1.6.0

2 release files

1.5.1

2 release files

1.5.0

2 release files

1.4.0

2 release files

1.3.1

2 release files

1.3.0

2 release files

1.2.0

2 release files

1.1.2

2 release files

1.1.1

2 release files

1.1.0

2 release files

1.0.3

2 release files

1.0.2

2 release files

1.0.1

2 release files

1.0.0

2 release files

0.7.0

2 release files

0.6.1

2 release files

0.6.0

2 release files

0.5.0

2 release files

0.4.0

2 release files

0.3.0

2 release files

0.2.0

2 release files

0.1.4

2 release files

0.1.3

2 release files

0.1.2

2 release files

0.1.1

2 release files

0.1.0

2 release files

Anthropic, PBC Visionary sponsor Bloomberg Visionary sponsor Hudson River Trading Visionary sponsor Meta Visionary sponsor NVIDIA Visionary sponsor Microsoft Sustainability sponsor Depot Continuous Integration AWS Cloud computing and Security Sponsor Datadog Monitoring Fastly CDN Google Download Analytics Sentry Error logging StatusPage Status page